/***********************************************************************/
/*                                                                     */
/*                            Pio (Fortran)                            */
/*                                                                     */
/*                    Polyglot Input/Output Library                    */
/*                                                                     */
/*               EPI Pomdapi, INRIA Paris - Rocquencourt               */
/*                                                                     */
/*  Copyright 2005-2014 INRIA.                                         */
/*  Institut National de Recherche en Informatique et en Automatique.  */
/*  All rights reserved. This file is distributed only by permission.  */
/*                                                                     */
/*  Francois Clement <Francois.Clement@inria.fr>                       */
/*  Pierre Weis <Pierre.Weis@inria.fr>                                 */
/*  Hend Ben Ameur <hbenameur@yahoo.ca>                                */
/*                                                                     */
/***********************************************************************/

/* $Id: pio_memory_mapping_constants.h,v 1.9 2014/01/10 19:22:10 fclement Exp $ */

#ifndef _PIO_MEMORY_MAPPING_CONSTANTS_H_
#define _PIO_MEMORY_MAPPING_CONSTANTS_H_

/* Maximum size of the memory mapping. */
#define MEMORY_MAPPING_SIZE (6 + MAX_VALUE_NUMBER * (6 + 2 * MAX_ARRAY_DIMENSION))
#define MIN_MEMORY_MAPPING_LOCATION FIRST_POINTER
#define MAX_MEMORY_MAPPING_LOCATION (MIN_MEMORY_MAPPING_LOCATION + MEMORY_MAPPING_SIZE - 1)

/* Respective addresses of communication components into the memory mapping. */
/* Slot Tc */
#define SLOT_COMMUNICATION_TYPE 1
/* Slot Nv */
#define SLOT_VALUES_NUMBER 2
/* Slot bs */
#define SLOT_NAME_BEGIN 3
/* Slot es */
#define SLOT_NAME_END 4
/* Slot bc */
#define SLOT_COMMUNICATION_BEGIN 5
/* Slot ec */
#define SLOT_COMMUNICATION_END 6
/* Slot vma */
#define SLOT_VALUE_DESCRIPTOR_ADDRESSES 7

#define SLOT_VALUE_DESCRIPTOR_ADDRESS(i) (SLOT_VALUE_DESCRIPTOR_ADDRESSES + i - 1)

/* Relative displacement wrt value descriptor pointer value_descriptor_ptr */
/* Slot Tv */
#define SLOT_VALUE_TYPE 0
/* Slot pv */
#define SLOT_VALUE_DIMENSION 1
#define SCALAR_DIMENSION 0
#define VECTOR_DIMENSION 1
#define MULTI_D_DIMENSION(p) (p)
/* Slot bv */
#define SLOT_VALUE_BEGIN 2
/* Slot ev */
#define SLOT_VALUE_END 3
/* Slot sizev */
#define SLOT_VALUE_SIZES_BEGIN 4
#define SLOT_VALUE_SIZES(i) (SLOT_VALUE_SIZES_BEGIN + i - 1)
/* Slot lkv */
#define SLOT_VALUE_LAYOUT_KIND(p) (SLOT_VALUE_SIZES_BEGIN + p)
/* Slot layoutv */
#define SLOT_VALUE_LAYOUT_BEGIN(p) (SLOT_VALUE_LAYOUT_KIND(p) + 1)
#define SLOT_VALUE_LAYOUT(p,i) (SLOT_VALUE_LAYOUT_BEGIN(p) + i - 1)
/* Slot lenv */
#define SLOT_VALUE_LENGTHS_BEGIN(p) (SLOT_VALUE_LAYOUT_BEGIN(p) + p)

/* Values to invalidate the communication components into the memory
   mapping. */
#define INVALID_COMMUNICATION_TYPE INVALID_NATURAL
#define INVALID_VALUES_NUMBER INVALID_NATURAL
#define INVALID_NAME_BEGIN INVALID_NATURAL
#define INVALID_NAME_END INVALID_SUCCESSOR
#define INVALID_COMMUNICATION_BEGIN INVALID_NATURAL
#define INVALID_COMMUNICATION_END INVALID_SUCCESSOR
#define INVALID_VALUES INVALID_NATURAL

#define INVALID_FETCH_VALUE_DESCRIPTOR_PTR INVALID_POINTER
#define INVALID_FETCH_VALUE_DESCRIPTOR_LIM INVALID_LIMIT
#define INVALID_STORE_VALUE_DESCRIPTOR_PTR INVALID_SUCCESSOR2
#define INVALID_FETCH_VALUE_NUMBER INVALID_POINTER
#define INVALID_STORE_VALUE_NUMBER INVALID_LIMIT

#define FIRST_VALUE_NUMBER FIRST_POINTER

#endif
