#######################################################################
#                                                                     #
#                                 Pph                                 #
#                                                                     #
#                    The Portable Project Handler                     #
#                                                                     #
#               EPI Pomdapi, INRIA Paris - Rocquencourt               #
#                                                                     #
#  Copyright 2005-2014 INRIA.                                         #
#  Institut National de Recherche en Informatique et en Automatique.  #
#  All rights reserved. This file is distributed only by permission.  #
#                                                                     #
#  Francois Clement <Francois.Clement@inria.fr>                       #
#  Pierre Weis <Pierre.Weis@inria.fr>                                 #
#                                                                     #
#######################################################################

# $Id: configure.profile,v 1.2 2014-01-31 16:17:08 fclement Exp $

# User configuration profile.
#
# This profile is sourced by the user configuration script ``configure_user''
# in the root directory of the Pph project.
# It assumes that the variable PROJECT_ROOT_DIR is set to an absolute path.

# Load user Pph system directory names.
. "${PROJECT_ROOT_DIR:?}"/pph/user/scripts/Pph_dirs.profile

# Load error codes.
. "${PPH_USER_SCRIPTS_DIR:?}"/error_codes.profile

# Load basic commands.
. "${PPH_USER_SCRIPTS_DIR:?}"/basic_commands.profile

# Load script functions.
. "${PPH_USER_SCRIPTS_DIR:?}"/script_functions.profile

# Load intrinsic defaults.
. "${PPH_USER_SCRIPTS_DIR:?}"/intrinsic_defaults.profile
DEVEL_MODE=false

# Load the ID card of the Pph project.
. "${PROJECT_CONFIG_DIR:?}"/Project.profile

# Create temporary configuration directories.
$MKDIR "${PROJECT_RUNTIME_DIR:?}"
$MKDIR "${PROJECT_CHECKPOINTS_DIR:?}"
$MKDIR "${PROJECT_SUMMARIES_DIR:?}"

# Load specific defaults if any.
PROJECT_SPECIFIC_DEFAULTS=false
PROFILE="${PROJECT_CONFIG_DIR:?}/specific_defaults.profile"
if test -f "$PROFILE"; then
    PROJECT_SPECIFIC_DEFAULTS=true
    . "$PROFILE"
fi

# Load additional options if any.
PROJECT_CONFIGURATION_ADDITIONAL_OPTIONS=false
PROFILE="${PROJECT_CONFIG_DIR:?}/configure_additional_options.profile"
if test -f "$PROFILE"; then
    PROJECT_CONFIGURATION_ADDITIONAL_OPTIONS=true
    . "$PROFILE"
fi

# Define configuration usage.
. "${PPH_USER_SCRIPTS_DIR:?}"/configure_usage.profile

# Parse configuration options.
. "${PPH_USER_SCRIPTS_DIR:?}"/configure_parsing.profile

report_message "Profile launched"

# Process user configuration options.
FOR_DEVELOPERS=false
. "${PPH_USER_SCRIPTS_DIR:?}"/configure_process_options.profile

# Unpack private tools.
report_message "Unpacking private tools"
untar_private_tools \
    "false" "${PRIVATE_TOOL:?}" "${PROJECT_TARBALLS_DIR:?}" 2>&1
IER=$?
if test $IER -ne 0; then
    $CAT "${USER_CONFIGURE_PROFILE_LOG:?}" 1>&2
    exit $IER
fi

#
# Build and install the Pph core pervasive tools (i.e., Htmlc).
#
$MKDIR "${PPH_BIN_DIR:?}"
install_pph_pervasive_tools "false" "${PPH_CORE_PERVASIVE_TOOLS:?}" 2>&1
IER=$?
if test $IER -ne 0; then
    $CAT "${USER_CONFIGURE_PROFILE_LOG:?}" 1>&2
    exit $IER
fi

#
# Create the ``.Project_path'' file in the root directory of the Pph project.
#
report_message "Creating project path in the root directory"
create_path_file "." "." "${PROJECT_PATH_FILE:?}" 2>&1
IER=$?
if test $IER -ne 0; then
    $CAT "${USER_CONFIGURE_PROFILE_LOG:?}" 1>&2
    exit $IER
fi

#
# Create the ``.Project_path'' file in the source directory of the Pph user
# pervasive tools. There are none for the moment...
#
UPT="user pervasives tools"
report_message "Creating project path in the source directory of Pph $UPT"
create_path_file_in_pph_pervasive_tools "$PPH_USER_PERVASIVE_TOOLS" 2>&1
IER=$?
if test $IER -ne 0; then
    $CAT "${USER_CONFIGURE_PROFILE_LOG:?}" 1>&2
    exit $IER
fi

#
# Create the user Pph preamble ``.User_preamble.pph'' in the root directory of
# the Pph project.
#
report_message "Creating user preamble"
create_user_preamble "${USER_PREAMBLE_FILE:?}" "${PROJECT_PATH_FILE:?}" 2>&1
IER=$?
if test $IER -ne 0; then
    $CAT "${USER_CONFIGURE_PROFILE_LOG:?}" 1>&2
    exit $IER
fi

#
# Remaining user configuration phase using makefiles.
# This is for the propagation of the preamble.
# Do not forget to exit on errors.
#

report_message "Launching user's configuration makefile"
$MAKE_COMMAND VERBOSITY_LEVEL=${VERBOSITY_LEVEL:?} configure \
    1> "${USER_MAKE_CONFIGURE_LOG:?}" 2>&1
IER=$?
if test $IER -ne 0; then
    $CAT "${USER_CONFIGURE_PROFILE_LOG:?}" 1>&2
    $CAT "${USER_MAKE_CONFIGURE_LOG:?}" 1>&2
    exit $IER
fi

#
# Build and install the Pph user pervasive tools (i.e., none).
# This could be done using makefiles, but it seems more convenient to use
# the same script function than for the core pervasive tools (in particular,
# using makefiles, it would be a non recursive task).
#
$MKDIR "${PPH_BIN_DIR:?}" && \
install_pph_pervasive_tools "false" "$PPH_USER_PERVASIVE_TOOLS" 2>&1
IER=$?
if test $IER -ne 0; then
    $CAT "${USER_CONFIGURE_PROFILE_LOG:?}" 1>&2
    exit $IER
fi

# Memorize the configure options.
if test -n "$CONFIGURE_OPTIONS"; then
    $ECHO "$CONFIGURE_OPTIONS" 1> "${USER_CONFIGURE_CMD_LINE_ARGS:?}"
else
#   Keep an eventually already existing file.
    $TOUCH "${USER_CONFIGURE_CMD_LINE_ARGS:?}" 2>&1
fi
IER=$?
if test $IER -ne 0; then
    $CAT "${USER_CONFIGURE_PROFILE_LOG:?}" 1>&2
    exit $IER
fi

report_message "Profile done"
